@@ -8,18 +8,20 @@ from .client import Client
 
 logger = logging.getLogger("thousandwords.cli")
 
-def login(instance = None) -> None:
+def login(args) -> None:
+  instance = args.instance
   try:
     curr_instance = CONFIG.instance
   except:
-    curr_instance = "1000words-hq.com"
+    curr_instance = None
   while not instance:
     prompt = "1000words instance URL [%s]: " % (
-      curr_instance or "e.g.: "
+      curr_instance or "e.g.: 1000words-hq.com"
     )
     instance = input(prompt).strip()
     if not instance:
       instance = curr_instance
+
   CONFIG.instance = instance
   CONFIG.save(update_default_instance=True)
 
@@ -39,9 +41,9 @@ def cells_run(args):
   resp = Client().run_cell(req)
   print(f"Successfully ran cell: {resp}")
 
-def storage_put(args):
+def storage_upload(args):
   with open(args.file) as f:
-    key = Client().put_protected(args.key, f.read())
+    key = Client().upload(args.key, f.read())
   print(f"Successfully created object with key: {key}")
 
 def storage_get(args):
@@ -50,9 +52,9 @@ def storage_get(args):
 
 STORAGE_COMMANDS = [
   {
-    "name": "put",
-    "help": "put value in store",
-    "handler": storage_put
+    "name": "upload",
+    "help": "upload value in store",
+    "handler": storage_upload
   },
   {
     "name": "get",
@@ -78,7 +80,7 @@ COMMANDS = [
   {
     "name": "login",
     "help": "authenticate thousandwords cli",
-    "handler": lambda args: login(args.instance),
+    "handler": login,
   },
   {
     "name": "cells",
@@ -142,7 +144,7 @@ def main():
             )
         if cmd["name"] == "storage":
           p.add_argument("key", help='object key')
-          if subcmd["name"] == "put":
+          if subcmd["name"] == "upload":
             p.add_argument("file", help="file with data for object")
 
   args = parser.parse_args()
