@@ -4,7 +4,7 @@ from python_graphql_client import GraphqlClient
 from typing import Optional
 import boto3
 from requests_aws4auth import AWS4Auth
-from thousandwords.auth import CognitoJwtAuth
+from thousandwords.auth import CognitoJwtAuth, CognitoAuth
 from thousandwords.config import CONFIG
 from thousandwords.credentials import CognitoCredentials
 
@@ -51,7 +51,12 @@ class Client:
         }
       }
     """
-    ret = self._get_gql_client('AMAZON_COGNITO_USER_POOLS').execute(
+    if CognitoAuth().is_authd():
+      auth_type = 'AMAZON_COGNITO_USER_POOLS'
+    else:
+      # fallback to guest (public iam)
+      auth_type = 'AWS_IAM'
+    ret = self._get_gql_client(auth_type).execute(
       query=query, variables={"input": input}
     )
     if "errors" in ret:
@@ -98,9 +103,8 @@ class Client:
       self._s3 = self._get_session().client('s3')
     return self._s3
   
-  def put_protected(self, key, value):
-    identity_id = self._cognito_creds.credentials['IdentityId']
-    key = f'protected/{identity_id}/{key}'
+  def upload(self, key, value):
+    key = f'uploads/{key}'
     resp = self.s3.put_object(
       Key=key,
       Bucket=CONFIG.storage_bucket,
